Module preprocess

Module preprocess 

Available on crate feature preprocess only.
Loading and preprocessing of ‘slang’ shader source files.

This module contains facilities and types for resolving #include directives in .slang into a single compilation unit. #pragma directives are also parsed and resolved as ShaderParameter structs.

The resulting ShaderSource can then be passed into a reflection target for reflection and compilation into the target shader format.

Structs

ShaderParameter
A user tweakable parameter for the shader as declared in source.
ShaderSource
The source file for a single shader pass.

Enums

PreprocessError
Error type for source preprocessing.