pub struct ShaderSource {
pub vertex: String,
pub fragment: String,
pub name: Option<ParamString>,
pub parameters: SizedHashMap<ParamString, ShaderParameter, BuildHasherDefault<FxHasher>>,
pub format: ImageFormat,
}Available on crate feature
preprocess only.Expand description
The source file for a single shader pass.
Fields
vertex: StringThe source contents for the vertex shader.
fragment: StringThe source contents for the fragment shader.
name: Option<ParamString>The alias of the shader if available.
parameters: SizedHashMap<ParamString, ShaderParameter, BuildHasherDefault<FxHasher>>The list of shader parameters found in the shader source.
format: ImageFormatThe image format the shader expects.
Implementations
Sourceimpl ShaderSource
impl ShaderSource
Sourcepub fn load(
path: impl AsRef<Path>,
features: ShaderFeatures,
) -> Result<ShaderSource, PreprocessError>
pub fn load( path: impl AsRef<Path>, features: ShaderFeatures, ) -> Result<ShaderSource, PreprocessError>
Load the source file at the given path, resolving includes relative to the location of the source file.